@@ -1,7 +1,7 @@
 
 /*
  * Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2007 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can  redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include <iostream>
 #include <map>
 #include <vector>
+#include <glib/gi18n.h>
 
 #include "gmstockicons.h"
 
@@ -95,7 +96,7 @@ static void on_core_updated (gpointer data);
  * BEHAVIOR     : 
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_source_added (Ekiga::Source &source,
+static void on_source_added (gmref_ptr<Ekiga::Source> source,
 			     gpointer data);
 
 
@@ -103,8 +104,8 @@ static void on_source_added (Ekiga::Source &source,
  * BEHAVIOR     : 
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static bool visit_books (Ekiga::Book &book,
-			 Ekiga::Source *source,
+static bool visit_books (gmref_ptr<Ekiga::Book> book,
+			 gmref_ptr<Ekiga::Source> source,
 			 gpointer data);
 
 
@@ -113,8 +114,8 @@ static bool visit_books (Ekiga::Book &book,
  * BEHAVIOR     : Add a view of the Book in the AddressBookWindow.
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_book_added (Ekiga::Source &source,
-			   Ekiga::Book &book,
+static void on_book_added (gmref_ptr<Ekiga::Source> source,
+			   gmref_ptr<Ekiga::Book> book,
                            gpointer data);
 
 
@@ -123,8 +124,8 @@ static void on_book_added (Ekiga::Source &source,
  * BEHAVIOR     : Remove the view of the Book from the AddressBookWindow.
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_book_removed (Ekiga::Source &source,
-			     Ekiga::Book &book,
+static void on_book_removed (gmref_ptr<Ekiga::Source> source,
+			     gmref_ptr<Ekiga::Book> book,
                              gpointer data);
 
 
@@ -133,8 +134,8 @@ static void on_book_removed (Ekiga::Source &source,
  * BEHAVIOR     : Update the Book in the AddressBookWindow.
  * PRE          : The given GtkWidget pointer must be an SearchBook GObject.
  */
-static void on_book_updated (Ekiga::Source &source,
-			     Ekiga::Book &book,
+static void on_book_updated (gmref_ptr<Ekiga::Source> source,
+			     gmref_ptr<Ekiga::Book> book,
                              gpointer data);
 
 /* DESCRIPTION  : Called when the ContactCore has a form request
@@ -186,7 +187,7 @@ static gint on_book_clicked (GtkWidget *tree_view,
  * PRE          : /
  */
 static void addressbook_window_add_book (AddressBookWindow * self,
-                                         Ekiga::Book &book);
+                                         gmref_ptr<Ekiga::Book> book);
 
 
 /* DESCRIPTION  : /
@@ -195,7 +196,7 @@ static void addressbook_window_add_book (AddressBookWindow * self,
  * PRE          : /
  */
 static void addressbook_window_update_book (AddressBookWindow *self,
-                                            Ekiga::Book &book);
+                                            gmref_ptr<Ekiga::Book> book);
 
 
 /* DESCRIPTION  : /
@@ -203,7 +204,7 @@ static void addressbook_window_update_book (AddressBookWindow *self,
  * PRE          : /
  */
 static void addressbook_window_remove_book (AddressBookWindow *self,
-                                            Ekiga::Book &book);
+                                            gmref_ptr<Ekiga::Book> book);
 
 
 /* DESCRIPTION  : /
@@ -214,7 +215,7 @@ static void addressbook_window_remove_book (AddressBookWindow *self,
  * PRE          : /
  */
 static gboolean find_iter_for_book (AddressBookWindow *addressbook_window,
-                                    Ekiga::Book &book,
+                                    gmref_ptr<Ekiga::Book> book,
                                     GtkTreeIter *iter);
 
 
@@ -239,7 +240,7 @@ on_core_updated (gpointer data)
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLOSE, self->priv->accel);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu_builder.menu), item);
   g_signal_connect_swapped (G_OBJECT (item), "activate",
-                            GTK_SIGNAL_FUNC (gtk_widget_hide),
+                            G_CALLBACK (gtk_widget_hide),
                             (gpointer) self);
 
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (self->priv->menu_item_core),
@@ -250,27 +251,27 @@ on_core_updated (gpointer data)
 
 
 static void
-on_source_added (Ekiga::Source &source,
+on_source_added (gmref_ptr<Ekiga::Source> source,
 		 gpointer data)
 {
-  source.visit_books (sigc::bind (sigc::ptr_fun (visit_books),
-				  &source, data));
+  source->visit_books (sigc::bind (sigc::ptr_fun (visit_books),
+				   source, data));
 }
 
 
-static bool visit_books (Ekiga::Book &book,
-			 Ekiga::Source *source,
+static bool visit_books (gmref_ptr<Ekiga::Book> book,
+			 gmref_ptr<Ekiga::Source> source,
 			 gpointer data)
 {
-  on_book_added (*source, book, data);
+  on_book_added (source, book, data);
 
   return true;
 }
 
 
 static void
-on_book_added (Ekiga::Source &/*source*/,
-	       Ekiga::Book &book,
+on_book_added (gmref_ptr<Ekiga::Source> /*source*/,
+	       gmref_ptr<Ekiga::Book> book,
                gpointer data)
 {
   addressbook_window_add_book (ADDRESSBOOK_WINDOW (data), book);
@@ -278,8 +279,8 @@ on_book_added (Ekiga::Source &/*source*/,
 
 
 static void
-on_book_removed (Ekiga::Source &/*source*/,
-		 Ekiga::Book &book,
+on_book_removed (gmref_ptr<Ekiga::Source> /*source*/,
+		 gmref_ptr<Ekiga::Book> book,
                  gpointer data)
 {
   addressbook_window_remove_book (ADDRESSBOOK_WINDOW (data), book);
@@ -287,8 +288,8 @@ on_book_removed (Ekiga::Source &/*source*/,
 
 
 static void
-on_book_updated (Ekiga::Source &/*source*/,
-		 Ekiga::Book &book,
+on_book_updated (gmref_ptr<Ekiga::Source> /*source*/,
+		 gmref_ptr<Ekiga::Book> book,
                  gpointer data)
 {
   addressbook_window_update_book (ADDRESSBOOK_WINDOW (data), book);
@@ -404,7 +405,7 @@ on_book_clicked (GtkWidget *tree_view,
                             NULL, NULL, NULL, NULL,
                             event->button, event->time);
             g_signal_connect (G_OBJECT (menu_builder.menu), "hide",
-                              GTK_SIGNAL_FUNC (g_object_unref),
+                              G_CALLBACK (g_object_unref),
                               (gpointer) menu_builder.menu);
           }
           g_object_ref_sink (G_OBJECT (menu_builder.menu));
@@ -421,7 +422,7 @@ on_book_clicked (GtkWidget *tree_view,
 /* Implementation of the private functions */
 static void
 addressbook_window_add_book (AddressBookWindow *self,
-                             Ekiga::Book &book)
+                             gmref_ptr<Ekiga::Book> book)
 {
   GtkTreeIter iter;
   GtkTreeModel *store = NULL;
@@ -439,19 +440,16 @@ addressbook_window_add_book (AddressBookWindow *self,
 
   g_signal_connect (view, "updated", G_CALLBACK (on_view_updated), self);
 
-  if (book.get_type () == "remote")
-    icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view), 
-                                   GM_STOCK_REMOTE_CONTACT, GTK_ICON_SIZE_MENU, NULL); 
-  else
-    icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view), 
-                                   GM_STOCK_LOCAL_CONTACT, GTK_ICON_SIZE_MENU, NULL); 
+  icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view),
+				 book->get_icon ().c_str (),
+				 GTK_ICON_SIZE_MENU, NULL); 
 
   store = gtk_tree_view_get_model (GTK_TREE_VIEW (self->priv->tree_view));
   gtk_tree_store_append (GTK_TREE_STORE (store), &iter, NULL);
   gtk_tree_store_set (GTK_TREE_STORE (store), &iter,
                       COLUMN_PIXBUF, icon, 
-                      COLUMN_NAME, book.get_name ().c_str (),
-                      COLUMN_BOOK_POINTER, &book, 
+                      COLUMN_NAME, book->get_name ().c_str (),
+                      COLUMN_BOOK_POINTER, &*book, 
                       COLUMN_VIEW, view,
                       -1);
 
@@ -467,7 +465,7 @@ addressbook_window_add_book (AddressBookWindow *self,
 
 static void
 addressbook_window_update_book (AddressBookWindow *self,
-                                Ekiga::Book &book)
+                                gmref_ptr<Ekiga::Book> book)
 {
   GtkTreeIter iter;
   GtkTreeModel *store = NULL;
@@ -475,14 +473,14 @@ addressbook_window_update_book (AddressBookWindow *self,
   store = gtk_tree_view_get_model (GTK_TREE_VIEW (self->priv->tree_view));
   if (find_iter_for_book (self, book, &iter))
     gtk_tree_store_set (GTK_TREE_STORE (store), &iter,
-                        COLUMN_NAME, book.get_name ().c_str (),
+                        COLUMN_NAME, book->get_name ().c_str (),
                         -1);
 }
 
 
 static void
 addressbook_window_remove_book (AddressBookWindow *self,
-                                Ekiga::Book &book)
+                                gmref_ptr<Ekiga::Book> book)
 {
   GtkTreeIter iter;
   gint page = -1;
@@ -519,7 +517,7 @@ addressbook_window_remove_book (AddressBookWindow *self,
 
 static gboolean
 find_iter_for_book (AddressBookWindow *self,
-                    Ekiga::Book &book,
+                    gmref_ptr<Ekiga::Book> book,
                     GtkTreeIter *iter)
 {
   Ekiga::Book *book_iter = NULL;
@@ -535,8 +533,10 @@ find_iter_for_book (AddressBookWindow *self,
                           COLUMN_BOOK_POINTER, &book_iter,
                           -1);
 
-      if (&book == book_iter)
+      if (&*book == book_iter) {
+
         break;
+      }
 
       if (!gtk_tree_model_iter_next (store, iter))
         return FALSE;
@@ -644,7 +644,6 @@ addressbook_window_new (Ekiga::ContactCore &core)
 
   sigc::connection conn;
 
-  GdkPixbuf *pixbuf = NULL;
   GtkWidget *menu_bar = NULL;
   GtkWidget *frame = NULL;
   GtkWidget *vbox = NULL;
@@ -660,11 +659,7 @@ addressbook_window_new (Ekiga::ContactCore &core)
   gtk_window_set_title (GTK_WINDOW (self), _("Address Book"));
   gtk_window_set_position (GTK_WINDOW (self), GTK_WIN_POS_CENTER);
 
-  pixbuf = gtk_widget_render_icon (GTK_WIDGET (self),
-				   GM_ICON_ADDRESSBOOK,
-				   GTK_ICON_SIZE_MENU, NULL);
-  gtk_window_set_icon (GTK_WINDOW (self), pixbuf);
-  g_object_unref (pixbuf);
+  gtk_window_set_icon_name (GTK_WINDOW (self), GM_ICON_ADDRESSBOOK);
 
   /* Start building the window */
   vbox = gtk_vbox_new (FALSE, 2);
