@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,10 +35,10 @@
  *
  */
 
-#include "config.h"
 
 #include <algorithm>
 #include <iostream>
+#include <glib/gi18n.h>
 
 #include "book-view-gtk.h"
 
@@ -46,83 +46,31 @@
 #include "menu-builder-tools.h"
 #include "menu-builder-gtk.h"
 
-/*
- * The signals centralizer relays signals from the Book to
- * the GObject and dies with it.
- */
-class SignalCentralizer: public sigc::trackable
-{
-public:
-
-  /* Watch the Book for changes,
-   * connect the signals
-   */
-  void watch_book (Ekiga::Book &book);
-
-  /* Repopulate the book */
-  void repopulate (Ekiga::Book &book);
-
-  /* signals emitted by this centralizer and of interest
-   * for our GObject
-   */
-  sigc::signal<void, Ekiga::Contact &> contact_added;
-  sigc::signal<void, Ekiga::Contact &> contact_updated;
-  sigc::signal<void, Ekiga::Contact &> contact_removed;
-  sigc::signal<void> updated;
-
-private:
-
-  void on_contact_added (Ekiga::Contact &contact);
-};
-
-
-void SignalCentralizer::watch_book (Ekiga::Book &book)
-{
-  book.contact_added.connect (contact_added.make_slot ());
-  book.contact_updated.connect (contact_updated.make_slot ());
-  book.contact_removed.connect (contact_removed.make_slot ());
-  book.updated.connect (updated.make_slot ());
-  repopulate (book);
-}
-
-
-void SignalCentralizer::repopulate (Ekiga::Book &book)
-{
-  book.visit_contacts (sigc::bind_return (sigc::mem_fun (this, &SignalCentralizer::on_contact_added), true));
-}
-
-
-void SignalCentralizer::on_contact_added (Ekiga::Contact &contact)
-{
-  contact_added.emit (contact);
-}
-
-
 /*
  * The Book View
  */
 struct _BookViewGtkPrivate
 {
-  _BookViewGtkPrivate (Ekiga::Book &_book) : book (_book) { }
+  _BookViewGtkPrivate (gmref_ptr<Ekiga::Book> book_) : book (book_) { }
 
-  SignalCentralizer centralizer;
   GtkTreeView *tree_view;
   GtkWidget *vbox;
   GtkWidget *entry;
   GtkWidget *statusbar;
   GtkWidget *scrolled_window;
 
-  Ekiga::Book &book;
+  gmref_ptr<Ekiga::Book> book;
+  std::list<sigc::connection> connections;
 };
 
 
-enum
-  {
-    COLUMN_CONTACT_POINTER,
-    COLUMN_PIXBUF,
-    COLUMN_NAME,
-    COLUMN_NUMBER
-  };
+enum {
+
+  COLUMN_CONTACT_POINTER,
+  COLUMN_PIXBUF,
+  COLUMN_NAME,
+  COLUMN_NUMBER
+};
 
 static GObjectClass *parent_class = NULL;
 
@@ -136,7 +84,7 @@ static GObjectClass *parent_class = NULL;
  * BEHAVIOR     : Update the BookView.
  * PRE          : The gpointer must point to the BookViewGtk GObject.
  */
-static void on_contact_added (Ekiga::Contact &contact,
+static void on_contact_added (gmref_ptr<Ekiga::Contact> contact,
 			      gpointer data);
 
 
@@ -144,7 +92,7 @@ static void on_contact_added (Ekiga::Contact &contact,
  * BEHAVIOR     : Update the BookView.
  * PRE          : The gpointer must point to the BookViewGtk GObject.
  */
-static void on_contact_updated (Ekiga::Contact &contact,
+static void on_contact_updated (gmref_ptr<Ekiga::Contact> contact,
 				gpointer data);
 
 
@@ -159,7 +107,7 @@ static void on_updated (gpointer data);
  * BEHAVIOR     : Update the BookView.
  * PRE          : The gpointer must point to the BookViewGtk GObject.
  */
-static void on_contact_removed (Ekiga::Contact &contact,
+static void on_contact_removed (gmref_ptr<Ekiga::Contact> contact,
 				gpointer data);
 
 
@@ -207,7 +155,7 @@ static gint on_contact_clicked (GtkWidget *tree_view,
  */
 static void
 book_view_gtk_add_contact (BookViewGtk *self,
-                           Ekiga::Contact &contact);
+                           gmref_ptr<Ekiga::Contact> contact);
 
 
 /* DESCRIPTION  : /
@@ -216,7 +164,7 @@ book_view_gtk_add_contact (BookViewGtk *self,
  */
 static void
 book_view_gtk_update_contact (BookViewGtk *self,
-                              Ekiga::Contact &contact,
+                              gmref_ptr<Ekiga::Contact> contact,
                               GtkTreeIter *iter);
 
 
@@ -226,7 +174,7 @@ book_view_gtk_update_contact (BookViewGtk *self,
  */
 static void
 book_view_gtk_remove_contact (BookViewGtk *self,
-                              Ekiga::Contact &contact);
+                              gmref_ptr<Ekiga::Contact> contact);
 
 
 /* DESCRIPTION  : /
@@ -236,14 +184,14 @@ book_view_gtk_remove_contact (BookViewGtk *self,
  */
 static gboolean
 book_view_gtk_find_iter_for_contact (BookViewGtk *view,
-                                     Ekiga::Contact &contact,
+                                     gmref_ptr<Ekiga::Contact> contact,
                                      GtkTreeIter *iter);
 
 
 
 /* Implementation of the callbacks */
 static void
-on_contact_added (Ekiga::Contact &contact,
+on_contact_added (gmref_ptr<Ekiga::Contact> contact,
 		  gpointer data)
 {
   book_view_gtk_add_contact (BOOK_VIEW_GTK (data), contact);
@@ -251,7 +199,7 @@ on_contact_added (Ekiga::Contact &contact,
 
 
 static void
-on_contact_updated (Ekiga::Contact &contact,
+on_contact_updated (gmref_ptr<Ekiga::Contact> contact,
 		    gpointer data)
 {
   BookViewGtk *view = NULL;
@@ -272,7 +220,7 @@ on_updated (gpointer data)
 
   view = BOOK_VIEW_GTK (data);
 
-  std::string status = view->priv->book.get_status ();
+  std::string status = view->priv->book->get_status ();
 
   gtk_statusbar_pop (GTK_STATUSBAR (view->priv->statusbar), 0);
   gtk_statusbar_push (GTK_STATUSBAR (view->priv->statusbar), 0, status.c_str ());
@@ -284,7 +232,7 @@ on_updated (gpointer data)
 
 
 static void
-on_contact_removed (Ekiga::Contact &contact,
+on_contact_removed (gmref_ptr<Ekiga::Contact> contact,
 		    gpointer data)
 {
   BookViewGtk *view = NULL;
@@ -307,15 +255,13 @@ on_entry_activated_cb (GtkWidget *entry,
                        gpointer data)
 {
   GdkCursor *cursor = NULL;
-
-  Ekiga::Book &book = BOOK_VIEW_GTK (data)->priv->book;
   const char *entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
 
   cursor = gdk_cursor_new (GDK_WATCH);
   gdk_window_set_cursor (GTK_WIDGET (data)->window, cursor);
   gdk_cursor_unref (cursor);
 
-  book.set_search_filter (entry_text);
+  BOOK_VIEW_GTK (data)->priv->book->set_search_filter (entry_text);
 }
 
 
@@ -337,7 +283,6 @@ on_contact_clicked (GtkWidget *tree_view,
   GtkTreePath *path = NULL;
   GtkTreeIter iter;
   GtkTreeModel *model = NULL;
-  Ekiga::Contact *contact = NULL;
 
   if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (tree_view),
 				     (gint) event->x, (gint) event->y,
@@ -348,6 +293,7 @@ on_contact_clicked (GtkWidget *tree_view,
 
     if (gtk_tree_model_get_iter (model, &iter, path)) {
 
+      Ekiga::Contact *contact = NULL;
       gtk_tree_model_get (model, &iter,
 			  COLUMN_CONTACT_POINTER, &contact,
 			  -1);
@@ -359,7 +305,7 @@ on_contact_clicked (GtkWidget *tree_view,
 	  Ekiga::TemporaryMenuBuilder temp;
 	  MenuBuilderGtk builder;
 
-	  BOOK_VIEW_GTK (data)->priv->book.populate_menu (temp);
+	  BOOK_VIEW_GTK (data)->priv->book->populate_menu (temp);
 	  contact->populate_menu (builder);
 
 	  if (!temp.empty ()) {
@@ -374,7 +320,7 @@ on_contact_clicked (GtkWidget *tree_view,
 	    gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
 			    NULL, NULL, event->button, event->time);
 	    g_signal_connect (G_OBJECT (builder.menu), "hide",
-			      GTK_SIGNAL_FUNC (g_object_unref),
+			      G_CALLBACK (g_object_unref),
 			      (gpointer) builder.menu);
 	  }
 	  g_object_ref_sink (G_OBJECT (builder.menu));
@@ -396,7 +342,7 @@ on_contact_clicked (GtkWidget *tree_view,
 /* Implementation of the static functions */
 static void
 book_view_gtk_add_contact (BookViewGtk *self,
-                           Ekiga::Contact &contact)
+                           gmref_ptr<Ekiga::Contact> contact)
 {
   GtkTreeModel *model = NULL;
   GtkListStore *store = NULL;
@@ -406,26 +352,26 @@ book_view_gtk_add_contact (BookViewGtk *self,
   store = GTK_LIST_STORE (model);
 
   gtk_list_store_append (store, &iter);
-  gtk_list_store_set (store, &iter, COLUMN_CONTACT_POINTER, &contact, -1);
+  gtk_list_store_set (store, &iter, COLUMN_CONTACT_POINTER, &*contact, -1);
   book_view_gtk_update_contact (self, contact, &iter);
 }
 
 
 static void
 book_view_gtk_update_contact (BookViewGtk *self,
-			      Ekiga::Contact &contact,
+			      gmref_ptr<Ekiga::Contact> contact,
 			      GtkTreeIter *iter)
 {
   GdkPixbuf *icon = NULL;
   GtkListStore *store = NULL;
 
   store = GTK_LIST_STORE (gtk_tree_view_get_model (self->priv->tree_view));
-  icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view), 
-                                 GM_STOCK_STATUS_UNKNOWN, GTK_ICON_SIZE_MENU, NULL); 
+  icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view),
+                                 GM_STOCK_STATUS_UNKNOWN, GTK_ICON_SIZE_MENU, NULL);
 
   gtk_list_store_set (store, iter,
                       COLUMN_PIXBUF, icon,
-		      COLUMN_NAME, contact.get_name ().c_str (),
+		      COLUMN_NAME, contact->get_name ().c_str (),
 		      -1);
   g_object_unref (icon);
 
@@ -436,7 +382,7 @@ book_view_gtk_update_contact (BookViewGtk *self,
 
 static void
 book_view_gtk_remove_contact (BookViewGtk *self,
-                              Ekiga::Contact &contact)
+                              gmref_ptr<Ekiga::Contact> contact)
 {
   GtkTreeModel *model = NULL;
   GtkListStore *store = NULL;
@@ -455,11 +401,10 @@ book_view_gtk_remove_contact (BookViewGtk *self,
 
 static gboolean
 book_view_gtk_find_iter_for_contact (BookViewGtk *view,
-                                     Ekiga::Contact &contact,
+                                     gmref_ptr<Ekiga::Contact> contact,
                                      GtkTreeIter *iter)
 {
   GtkTreeModel *model = NULL;
-  Ekiga::Contact *iter_contact = NULL;
   gboolean found = FALSE;
 
   model = gtk_tree_view_get_model (view->priv->tree_view);
@@ -468,10 +413,11 @@ book_view_gtk_find_iter_for_contact (BookViewGtk *view,
 
     do {
 
+      Ekiga::Contact *iter_contact = NULL;
       gtk_tree_model_get (model, iter,
                           COLUMN_CONTACT_POINTER, &iter_contact,
                           -1);
-      if (iter_contact == &contact)
+      if (iter_contact == &*contact)
         found = TRUE;
 
     } while (!found && gtk_tree_model_iter_next (model, iter));
@@ -489,6 +435,12 @@ book_view_gtk_dispose (GObject *obj)
 
   view = BOOK_VIEW_GTK (obj);
 
+  for (std::list<sigc::connection>::iterator iter
+	 = view->priv->connections.begin ();
+       iter != view->priv->connections.end ();
+       ++iter)
+    iter->disconnect ();
+
   if (view->priv->tree_view) {
 
     g_signal_handlers_disconnect_matched (gtk_tree_view_get_selection (view->priv->tree_view),
@@ -571,7 +523,7 @@ book_view_gtk_get_type ()
 
 /* public methods implementation */
 GtkWidget *
-book_view_gtk_new (Ekiga::Book &book)
+book_view_gtk_new (gmref_ptr<Ekiga::Book> book)
 {
   BookViewGtk *result = NULL;
 
@@ -661,14 +613,15 @@ book_view_gtk_new (Ekiga::Book &book)
   result->priv->statusbar = gtk_statusbar_new ();
   gtk_box_pack_start (GTK_BOX (result->priv->vbox), result->priv->statusbar, FALSE, TRUE, 0);
 
+  /* connect to the signals */
+  result->priv->connections.push_back (book->contact_added.connect (sigc::bind (sigc::ptr_fun (on_contact_added), (gpointer)result)));
+  result->priv->connections.push_back (book->contact_updated.connect (sigc::bind (sigc::ptr_fun (on_contact_updated), (gpointer)result)));
+  result->priv->connections.push_back (book->contact_removed.connect (sigc::bind (sigc::ptr_fun (on_contact_removed), (gpointer)result)));
+  result->priv->connections.push_back (book->updated.connect (sigc::bind (sigc::ptr_fun (on_updated), (gpointer)result)));
 
-  /* Relay signals */
-  result->priv->centralizer.contact_added.connect (sigc::bind (sigc::ptr_fun (on_contact_added), (gpointer)result));
-  result->priv->centralizer.contact_updated.connect (sigc::bind (sigc::ptr_fun (on_contact_updated), (gpointer)result));
-  result->priv->centralizer.contact_removed.connect (sigc::bind (sigc::ptr_fun (on_contact_removed), (gpointer)result));
-  result->priv->centralizer.updated.connect (sigc::bind (sigc::ptr_fun (on_updated), (gpointer)result));
 
-  result->priv->centralizer.watch_book (book);
+  /* populate */
+  book->visit_contacts (sigc::bind_return (sigc::bind (sigc::ptr_fun (on_contact_added), (gpointer)result),true));
 
   return (GtkWidget *) result;
 }
@@ -688,7 +641,7 @@ book_view_gtk_populate_menu (BookViewGtk *self,
   GtkWidget *item = NULL;
   MenuBuilderGtk builder (menu);
 
-  self->priv->book.populate_menu (builder);
+  self->priv->book->populate_menu (builder);
 
   selection = gtk_tree_view_get_selection (self->priv->tree_view);
 
