@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include <sstream>
 #include <iostream>
 #include <iomanip>
+#include <glib/gi18n.h>
 
 #include "call-history-view-gtk.h"
 
@@ -68,7 +69,7 @@ destroy_connections (gpointer data,
 
 /* react to a new call being inserted in history */
 static void
-on_contact_added (Ekiga::Contact &contact,
+on_contact_added (gmref_ptr<Ekiga::Contact> contact,
 		  GtkListStore *store)
 {
   time_t t;
@@ -77,12 +78,10 @@ on_contact_added (Ekiga::Contact &contact,
   std::stringstream info;
   const gchar *id = NULL;
 
-  History::Contact *hcontact = NULL;
+  gmref_ptr<History::Contact> hcontact = contact;
   GtkTreeIter iter;
 
-  hcontact = dynamic_cast<History::Contact*>(&contact);
-
-  if (hcontact != NULL) {
+  if (hcontact) {
 
     switch (hcontact->get_type ()) {
 
@@ -119,9 +118,9 @@ on_contact_added (Ekiga::Contact &contact,
 
   gtk_list_store_prepend (store, &iter);
   gtk_list_store_set (store, &iter,
-		      COLUMN_CONTACT, &contact,
+		      COLUMN_CONTACT, &*contact,
 		      COLUMN_PIXBUF, id,
-		      COLUMN_NAME, contact.get_name ().c_str (),
+		      COLUMN_NAME, contact->get_name ().c_str (),
 		      COLUMN_INFO, info.str ().c_str (),
 		      -1);
 }
@@ -160,13 +159,13 @@ on_clicked (GtkWidget *tree,
 	  contact->populate_menu (builder);
 	if (!builder.empty())
 	  builder.add_separator ();
-	builder.add_action ("clear", _("Clear"),
+	builder.add_action ("clear", _("Clear List"),
 			    sigc::mem_fun (book, &History::Book::clear));
 	gtk_widget_show_all (builder.menu);
 	gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
 			NULL, NULL, event->button, event->time);
 	g_signal_connect (G_OBJECT (builder.menu), "hide",
-			  GTK_SIGNAL_FUNC (g_object_unref),
+			  G_CALLBACK (g_object_unref),
 			  (gpointer) builder.menu);
 	g_object_ref_sink (G_OBJECT (builder.menu));
       }
@@ -190,7 +189,7 @@ on_clicked (GtkWidget *tree,
 /* public api */
 
 GtkWidget *
-call_history_view_gtk_new (History::Book &book)
+call_history_view_gtk_new (gmref_ptr<History::Book> book)
 {
   GtkWidget *result = NULL;
   std::list<sigc::connection> *conns = NULL;
@@ -245,16 +244,16 @@ call_history_view_gtk_new (History::Book &book)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
   g_signal_connect (G_OBJECT (tree), "event-after",
-		    G_CALLBACK (on_clicked), &(book));
+		    G_CALLBACK (on_clicked), &book);
 
   /* connect to the signals */
-  connection = book.cleared.connect (sigc::bind (sigc::ptr_fun (gtk_list_store_clear), store));
+  connection = book->cleared.connect (sigc::bind (sigc::ptr_fun (gtk_list_store_clear), store));
   conns->push_front (connection);
-  connection = book.contact_added.connect (sigc::bind (sigc::ptr_fun (on_contact_added), store));
+  connection = book->contact_added.connect (sigc::bind (sigc::ptr_fun (on_contact_added), store));
   conns->push_front (connection);
 
   /* populate */
-  book.visit_contacts (sigc::bind_return(sigc::bind (sigc::ptr_fun (on_contact_added), store), true));
+  book->visit_contacts (sigc::bind_return(sigc::bind (sigc::ptr_fun (on_contact_added), store), true));
 
   return result;
 }
