@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2008 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
  *
  */
 
-#include "config.h"
 
 #include "chat-area.h"
 #include "gm-text-buffer-enhancer.h"
@@ -51,6 +50,7 @@
 #include <string.h>
 #include <stdarg.h>
 
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
 class ChatAreaHelper;
@@ -59,7 +59,7 @@ struct _ChatAreaPrivate
 {
   Ekiga::Chat* chat;
   sigc::connection connection;
-  ChatAreaHelper* helper;
+  gmref_ptr<ChatAreaHelper> helper;
   GmTextBufferEnhancer* enhancer;
   GtkWidget* smiley_menu;
 
@@ -638,9 +638,8 @@ chat_area_finalize (GObject* obj)
 
     self->priv->connection.disconnect ();
     if (self->priv->helper) {
-      self->priv->chat->disconnect (*(self->priv->helper));
-      delete self->priv->helper;
-      self->priv->helper = NULL;
+      self->priv->chat->disconnect (self->priv->helper);
+      self->priv->helper.reset ();
     }
     self->priv->chat = NULL;
   }
@@ -687,8 +686,8 @@ chat_area_set_property (GObject* obj,
     ptr = g_value_get_pointer (value);
     self->priv->chat = (Ekiga::Chat *)ptr;
     self->priv->connection = self->priv->chat->removed.connect (sigc::bind (sigc::ptr_fun (on_chat_removed), self));
-    self->priv->helper = new ChatAreaHelper (self);
-    self->priv->chat->connect (*(self->priv->helper));
+    self->priv->helper = gmref_ptr<ChatAreaHelper>(new ChatAreaHelper (self));
+    self->priv->chat->connect (self->priv->helper);
     break;
 
   default:
@@ -965,7 +964,7 @@ chat_area_init (GTypeInstance* instance,
   gtk_box_pack_start (GTK_BOX (vbox), self->priv->message,
 		      TRUE, TRUE, 2);
 
-  gtk_widget_set_size_request (GTK_WIDGET (vbox), 175, -1);
+  gtk_widget_set_size_request (GTK_WIDGET (self->priv->message), 155, -1);
   gtk_widget_show_all (vbox);
 
   g_signal_connect (G_OBJECT (self), "focus",
@@ -1007,10 +1006,10 @@ chat_area_get_type ()
 /* public api */
 
 GtkWidget*
-chat_area_new (Ekiga::Chat& chat)
+chat_area_new (gmref_ptr<Ekiga::Chat> chat)
 {
   return (GtkWidget*)g_object_new (TYPE_CHAT_AREA,
-				   "chat", &chat,
+				   "chat", &*chat,
 				   NULL);
 }
 
