@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 
 
 #include <gtk/gtk.h>
-#include <glib.h>
+#include <glib/gi18n.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -55,10 +55,6 @@
 #define vsnprintf _vsnprintf
 #endif
 
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif
-
 #include "config.h"
 
 
@@ -507,7 +503,7 @@ gnomemeeting_warning_dialog_on_widget (GtkWindow *parent,
   gnomemeeting_threads_dialog_show_all (dialog);
 
   g_signal_connect_data (GTK_OBJECT (dialog), "response",
-			 GTK_SIGNAL_FUNC (warning_dialog_destroyed_cb),
+			 G_CALLBACK (warning_dialog_destroyed_cb),
 			 (gpointer) g_strdup (key),
 			 (GClosureNotify) g_free,
 			 (GConnectFlags) 0);
