@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,8 +35,6 @@
  *   			    manipulate accounts.
  */
 
-#include "config.h"
-
 #include "accounts.h"
 
 #include "account.h"
@@ -49,9 +47,6 @@
 #include "main.h"
 #include "preferences.h"
 
-#include "manager.h"
-#include "ekiga.h"
-
 #include "gmconf.h"
 #include "gmdialog.h"
 
@@ -264,16 +259,14 @@ on_mwi_event (const Ekiga::Account & account,
               std::string mwi,
               gpointer self)
 {
-  GmAccountsWindow *aw = NULL;
-
-  aw = gm_aw_get_aw (GTK_WIDGET (self));
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (aw->core.get ("audiooutput-core"));
-
   if (gm_accounts_window_update_account_state (GTK_WIDGET (self), false, account, NULL, mwi.c_str ())) {
 
     std::string::size_type loc = mwi.find ("/", 0);
     if (loc != std::string::npos) {
 
+      GmAccountsWindow *aw = gm_aw_get_aw (GTK_WIDGET (self));
+      gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core
+	= aw->core.get ("audiooutput-core");
       std::stringstream new_messages;
       int i;
       new_messages << mwi.substr (0, loc);
@@ -304,7 +297,8 @@ populate_menu (GtkWidget *window)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
 
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (aw->core.get ("account-core"));
+  gmref_ptr<Ekiga::AccountCore> account_core
+    = aw->core.get ("account-core");
 
   if (account_core->populate_menu (builder)) {
     item = gtk_separator_menu_item_new ();
@@ -325,7 +319,7 @@ populate_menu (GtkWidget *window)
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLOSE, aw->accel);
   gtk_menu_shell_append (GTK_MENU_SHELL (builder.menu), item);
   g_signal_connect_swapped (G_OBJECT (item), "activate",
-                            GTK_SIGNAL_FUNC (gtk_widget_hide),
+                            G_CALLBACK (gtk_widget_hide),
                             (gpointer) window);
 
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (aw->menu_item_core),
@@ -379,7 +373,7 @@ account_clicked_cb (G_GNUC_UNUSED GtkWidget *w,
             gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
                             NULL, NULL, event->button, event->time);
             g_signal_connect (G_OBJECT (builder.menu), "hide",
-                              GTK_SIGNAL_FUNC (g_object_unref),
+                              G_CALLBACK (g_object_unref),
                               (gpointer) builder.menu);
           }
           g_object_ref_sink (G_OBJECT (builder.menu));
@@ -763,7 +757,8 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   /* Engine Signals callbacks */
   // FIXME sigc::connection conn;
 
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (core.get ("account-core"));
+  gmref_ptr<Ekiga::AccountCore> account_core
+    = core.get ("account-core");
   account_core->bank_added.connect (sigc::bind (sigc::ptr_fun (on_bank_added), window));
   account_core->account_added.connect (sigc::bind (sigc::ptr_fun (on_account_added), window));
   account_core->account_updated.connect (sigc::bind (sigc::ptr_fun (on_account_updated), window));
