@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
  */
 
 
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "statusicon.h"
@@ -126,13 +127,13 @@ statusicon_set_inacall (StatusIcon *widget,
                         bool inacall);
 
 static void 
-established_call_cb (Ekiga::CallManager & manager,
-                     Ekiga::Call & call,
+established_call_cb (gmref_ptr<Ekiga::CallManager>  manager,
+                     gmref_ptr<Ekiga::Call>  call,
                      gpointer self);
 
 static void 
-cleared_call_cb (Ekiga::CallManager & manager,
-                 Ekiga::Call & call,
+cleared_call_cb (gmref_ptr<Ekiga::CallManager>  manager,
+                 gmref_ptr<Ekiga::Call>  call,
                  std::string reason,
                  gpointer self);
 
@@ -276,7 +277,7 @@ statusicon_activated_cb (G_GNUC_UNUSED GtkStatusIcon *icon,
   }
   else {
 
-    GtkFrontend *frontend = dynamic_cast<GtkFrontend*>(self->priv->core.get ("gtk-frontend"));
+    gmref_ptr<GtkFrontend> frontend = self->priv->core.get ("gtk-frontend");
     GtkWidget *w = GTK_WIDGET (frontend->get_chat_window ());
 
     gtk_widget_show (w);
@@ -323,13 +324,12 @@ statusicon_blink_cb (gpointer data)
 {
   StatusIcon *statusicon = STATUSICON (data);
 
-  GtkFrontend *frontend = NULL;
   GtkWidget *chat_window = NULL;
   GdkPixbuf *pixbuf = NULL;
 
   g_return_val_if_fail (data != NULL, false);
 
-  frontend = dynamic_cast<GtkFrontend*>(STATUSICON (data)->priv->core.get ("gtk-frontend"));
+  gmref_ptr<GtkFrontend> frontend = statusicon->priv->core.get ("gtk-frontend");
   // FIXME use main_window here
   chat_window = GTK_WIDGET (frontend->get_chat_window ());
 
@@ -349,15 +349,15 @@ statusicon_blink_cb (gpointer data)
 
 static void
 personal_details_updated_cb (StatusIcon* self,
-			     Ekiga::PersonalDetails* details)
+			     gmref_ptr<Ekiga::PersonalDetails> details)
 {
   statusicon_set_status (self, details->get_presence ());
 }
 
 
 static void 
-established_call_cb (Ekiga::CallManager & /*manager*/,
-                     Ekiga::Call & /*call*/,
+established_call_cb (gmref_ptr<Ekiga::CallManager>  /*manager*/,
+                     gmref_ptr<Ekiga::Call>  /*call*/,
                      gpointer self)
 {
   statusicon_set_inacall (STATUSICON (self), true);
@@ -365,8 +365,8 @@ established_call_cb (Ekiga::CallManager & /*manager*/,
 
 
 static void 
-cleared_call_cb (Ekiga::CallManager & /*manager*/,
-                 Ekiga::Call & /*call*/,
+cleared_call_cb (gmref_ptr<Ekiga::CallManager>  /*manager*/,
+                 gmref_ptr<Ekiga::Call>  /*call*/,
                  std::string /*reason*/,
                  gpointer self)
 {
@@ -383,10 +383,9 @@ statusicon_build_menu ()
   GtkWidget *main_window = NULL;
 
   Ekiga::ServiceCore *services = NULL;
-  GtkFrontend *gtk_frontend = NULL;
 
   services = GnomeMeeting::Process ()->GetServiceCore ();
-  gtk_frontend = dynamic_cast<GtkFrontend *>(services->get ("gtk-frontend"));
+  gmref_ptr<GtkFrontend> gtk_frontend = services->get ("gtk-frontend");
   main_window = GnomeMeeting::Process ()->GetMainWindow ();
 
   static MenuEntry menu [] =
@@ -394,19 +393,19 @@ statusicon_build_menu ()
       GTK_MENU_ENTRY("help", NULL,
                      _("Get help by reading the Ekiga manual"),
                      GTK_STOCK_HELP, GDK_F1,
-                     GTK_SIGNAL_FUNC (help_cb), NULL, TRUE),
+                     G_CALLBACK (help_cb), NULL, TRUE),
 
       GTK_MENU_ENTRY("about", NULL,
 		     _("View information about Ekiga"),
 		     GTK_STOCK_ABOUT, 0,
-		     GTK_SIGNAL_FUNC (about_callback), (gpointer) main_window,
+		     G_CALLBACK (about_callback), (gpointer) main_window,
 		     TRUE),
 
       GTK_MENU_SEPARATOR,
 
       GTK_MENU_ENTRY("quit", NULL, _("Quit"),
 		     GTK_STOCK_QUIT, 'Q',
-		     GTK_SIGNAL_FUNC (quit_callback),
+		     G_CALLBACK (quit_callback),
 		     main_window, TRUE),
 
       GTK_MENU_END
@@ -423,8 +422,13 @@ statusicon_start_blinking (StatusIcon *icon,
   g_return_if_fail (icon != NULL);
 
   icon->priv->blink_image = g_strdup (stock_id);
+#if GLIB_CHECK_VERSION (2, 14, 0)
+  if (icon->priv->blink_id == -1)
+    icon->priv->blink_id = g_timeout_add_seconds (1, statusicon_blink_cb, icon);
+#else
   if (icon->priv->blink_id == -1)
     icon->priv->blink_id = g_timeout_add (1000, statusicon_blink_cb, icon);
+#endif
 }
 
 
@@ -452,13 +456,12 @@ void
 statusicon_set_status (StatusIcon *statusicon,
                        const std::string & presence)
 {
-  GtkFrontend *frontend = NULL;
   GtkWidget *chat_window = NULL;
   GdkPixbuf *pixbuf = NULL;
 
   g_return_if_fail (statusicon != NULL);
 
-  frontend = dynamic_cast<GtkFrontend*>(statusicon->priv->core.get ("gtk-frontend"));
+  gmref_ptr<GtkFrontend> frontend = statusicon->priv->core.get ("gtk-frontend");
   // FIXME use main_window here
   chat_window = GTK_WIDGET (frontend->get_chat_window ());
 
@@ -485,13 +488,12 @@ void
 statusicon_set_inacall (StatusIcon *statusicon,
                         bool inacall)
 {
-  GtkFrontend *frontend = NULL;
   GtkWidget *chat_window = NULL;
   GdkPixbuf *pixbuf = NULL;
 
   g_return_if_fail (statusicon != NULL);
 
-  frontend = dynamic_cast<GtkFrontend*>(statusicon->priv->core.get ("gtk-frontend"));
+  gmref_ptr<GtkFrontend> frontend = statusicon->priv->core.get ("gtk-frontend");
   // FIXME use main_window here
   chat_window = GTK_WIDGET (frontend->get_chat_window ());
 
@@ -533,9 +535,9 @@ statusicon_new (Ekiga::ServiceCore & core)
   self->priv->blink_image = NULL;
   self->priv->unread_messages = false;
 
-  GtkFrontend *frontend = dynamic_cast<GtkFrontend*>(core.get ("gtk-frontend"));
-  Ekiga::PersonalDetails *details = dynamic_cast<Ekiga::PersonalDetails*> (core.get ("personal-details"));
-  Ekiga::CallCore *call_core = dynamic_cast<Ekiga::CallCore*> (core.get ("call-core"));
+  gmref_ptr<GtkFrontend> frontend = core.get ("gtk-frontend");
+  gmref_ptr<Ekiga::PersonalDetails> details = core.get ("personal-details");
+  gmref_ptr<Ekiga::CallCore> call_core = core.get ("call-core");
   GtkWidget *chat_window = GTK_WIDGET (frontend->get_chat_window ());
 
   statusicon_set_status (self, details->get_presence ());
